"use client";
import React, { useState, useRef } from "react";
import { Button } from "@/components/ui/button";
import { Input } from "@/components/ui/input";
import { Label } from "@/components/ui/label";
import { Loader2 } from "lucide-react";
import toast, { Toaster } from "react-hot-toast";
import { useRouter } from "next/navigation";
import Image from "next/image";
import { SiteLogo } from "@/components/svg";
import { useMediaQuery } from "@/hooks/use-media-query";
import "../(admin)/admin/assets/scss/globals.scss";
import "../(admin)/admin/assets/scss/theme.scss";
import "simplebar-react/dist/simplebar.min.css";
import "flatpickr/dist/themes/light.css";
import { useEffect } from "react";
import { postApiData, postApiFormData, getApiData } from "@/Helper/common";
import { Icon } from "@iconify/react";
import Link from "next/link";
import { RadioGroup, RadioGroupItem } from "@/components/ui/radio-group";
import { ArrowRightAlt } from "@mui/icons-material";


const Form = ({ themeData }) => {

  const [isPending, startTransition] = React.useState(false);
  const isDesktop2xl = useMediaQuery("(max-width: 1530px)");
  const [loadingOtpVerify, setLoadingOtpVerify] = useState(false);
  const [loadingOtpResend, setLoadingOtpResend] = useState(false);

  const [showOTP, setShowOTP] = useState(false);
  const [loading, setLoading] = useState(false);
  const [mobile, setMobile] = useState("");
  const [email, setEmail] = useState("");
  const [uniqueId, setUniqueId] = useState("");
  const [message, setMessage] = useState("");
  // const [unique_id, setUserId] = useState('');

  const totalOtpField = 4;
  const otpArray = Array.from({ length: totalOtpField }, () => "");
  const [otp, setOtp] = useState(otpArray);
  const otpFields = Array.from({ length: totalOtpField }, (_, index) => index);
  const inputRefs = useRef([]);

  const [countdown, setCountdown] = useState(0);
  const [isCounting, setIsCounting] = useState(true);
  const [otpType, setOtpType] = useState('mobile');
  const [data, setData] = useState(themeData);

  const [uniqueIdMobile, setUserIdMobile] = useState('');

  const [multipleUser, setMultipleUser] = useState(false);
  const [userCheckData, setUserCheckData] = useState(false);
  const [multipleUserAccount, setMultipleUserAccount] = useState([]);

  var apiCall = true;

  // submit register form
  const handleSubmit = async (e) => {
    e.preventDefault();

    if (userCheckData) {

      const apiData = new FormData();

      apiData.append("unique_id", uniqueId);
      apiData.append("otpType", otpType);

      toast.dismiss();

      if (!uniqueId.trim()) {
        toast.error("User Id is required", {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

      } else {
        try {
          setLoading(true);

          const data = await postApiFormData('admin/forgot-password', apiData);

          if (data.error == false) {
            toast.success(data.message, {
              position: "bottom-center",
              style: { borderRadius: "10px", background: "#333", color: "#fff" },
            });
            setShowOTP(true);
            setLoading(false);
            setMobile(data?.result?.phone);
            setEmail(data?.result?.email);
            setCountdown(120);
            setIsCounting(true);
          } else {
            toast.error(data.message, {
              position: "bottom-center",
              style: { borderRadius: "10px", background: "#333", color: "#fff" },
            });
            setLoading(false);
          }

        } catch (errorData) {
          toast.error(errorData.message, {
            position: "bottom-center",
            style: { borderRadius: "10px", background: "#333", color: "#fff" },
          });
          setLoading(false);
        }
      }

    } else {

      const apiData = JSON.stringify({ unique_id: uniqueIdMobile });

      toast.dismiss();

      if (!uniqueIdMobile.trim()) {

        toast.error('User Id / Mobile number is required', { position: "bottom-center", style: { borderRadius: '10px', background: '#333', color: '#fff' } });

      } else {

        startTransition(true);

        const dataRes = await postApiData("admin/check-multiple-user-login?ApiType=Web", apiData);

        if (dataRes && dataRes.error == false) {

          // toast.success(dataRes.message, { position: "bottom-center", style: { borderRadius: '10px', background: '#333', color: '#fff' } });
          // alert(dataRes.userType);

          if (dataRes && dataRes?.userType === 'single') {


            setMultipleUser(false);
            setUniqueId(dataRes?.result?.unique_id);
            // alert(dataRes?.result?.unique_id);

            const apiData = new FormData();

            apiData.append("unique_id", dataRes?.result?.unique_id);
            apiData.append("otpType", otpType);

            toast.dismiss();

            setLoading(true);

            const data = await postApiFormData('admin/forgot-password', apiData);

            if (data.error == false) {
              toast.success(data.message, {
                position: "bottom-center",
                style: { borderRadius: "10px", background: "#333", color: "#fff" },
              });
              setShowOTP(true);
              setLoading(false);
              setMobile(data?.result?.phone);
              setEmail(data?.result?.email);
              setCountdown(120);
              setIsCounting(true);
            } else {
              toast.error(data.message, {
                position: "bottom-center",
                style: { borderRadius: "10px", background: "#333", color: "#fff" },
              });
              setLoading(false);
            }


          } else if (dataRes?.userType == 'multiple') {

            // alert('sdsdsdsd');
            setMultipleUserAccount(dataRes.result);

            setMultipleUser(true);
            setUserCheckData(true);

          }
          startTransition(false);

        } else {

          toast.error(dataRes.message, { position: "bottom-center", style: { borderRadius: '10px', background: '#333', color: '#fff' } });
          startTransition(false);
        }

      }

    }

  };

  // otp verify
  async function onOTPVerify(event) {
    event.preventDefault();
    toast.dismiss();

    const OTP = otp.join("");

    const apiData = JSON.stringify({ phone: mobile, otp: OTP, unique_id: uniqueId, type: 'forgotPassword' });

    try {
      setLoadingOtpVerify(true);

      const data = await postApiData("admin/otp-verify", apiData);

      if (data.error == false) {
        toast.success(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

        setMessage(data.message);
        setShowOTP(false);
        setLoadingOtpVerify(false);
        setUniqueId('');
        setMobile('');
        setUserIdMobile('');
        setOtp(Array(otpFields.length).fill(''));


      } else {
        toast.error(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setLoadingOtpVerify(false);
        setOtp(Array(otpFields.length).fill(''));
      }
    } catch (errorData) {
      toast.error(errorData.message, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setLoadingOtpVerify(false);
      setOtp(Array(otpFields.length).fill(''));
    }

  }

  // send otp resend
  async function otpResend() {
    const apiData = JSON.stringify({ phone: mobile, unique_id: uniqueId, otpType });
    toast.dismiss();
    setOtp(Array(otpFields.length).fill(''));
    try {
      setLoadingOtpResend(true);

      const data = await postApiData("admin/otp-resend", apiData);

      if (data.error == false) {
        toast.success(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });

        setShowOTP(true);
        setLoadingOtpResend(false);
        setCountdown(120);
        setIsCounting(true);
      } else {
        toast.error(data.message, {
          position: "bottom-center",
          style: { borderRadius: "10px", background: "#333", color: "#fff" },
        });
        setLoadingOtpResend(false);
      }
    } catch (errorData) {
      toast.error(errorData.message, {
        position: "bottom-center",
        style: { borderRadius: "10px", background: "#333", color: "#fff" },
      });
      setLoadingOtpResend(false);
    }

    // Add logic to verify OTP here
  }


  const handleChange = (e, index) => {
    const { value } = e.target;
    if (!isNaN(value) && value.length <= 1) {
      const newOtp = [...otp];
      newOtp[index] = value;
      setOtp(newOtp);
      if (value.length === 1 && index < totalOtpField - 1) {
        inputRefs.current[index + 1].focus();
      }
    }
  };

  const handleKeyDown = (index, event) => {
    if (event.key === "Backspace" && otp[index] === "" && index > 0) {
      setOtp(prevOtp => {
        const newOtp = [...prevOtp];
        newOtp[index - 1] = "";
        return newOtp;
      });
      inputRefs.current[index - 1].focus();
    } else if (event.key === "ArrowLeft" && index > 0) {
      inputRefs.current[index - 1].focus();
    } else if (event.key === "ArrowRight" && index < numInputs - 1) {
      inputRefs.current[index + 1].focus();
    }
  };

  function formatMobileNumber(number) {

    if (otpType == 'mobile') {

      if (number) {

        var formattedNumber = "xxxxxx" + number.substring(6);
        return formattedNumber;
      } else {

        return "xxxxxxXXXX";
      }

    } else {
      return "xxxxxx" + email?.substring(6);
    }



  }


  const isOtpComplete = otp.every((digit) => digit !== "");
  const [isHovered, setIsHovered] = useState(false);

  useEffect(() => {
    if (isCounting && countdown > 0) {
      var timer = setInterval(() => {
        setCountdown(prevCountdown => prevCountdown - 1);
      }, 1000);
    } else if (countdown === 0) {
      setIsCounting(false);
    }
    return () => clearInterval(timer);
  }, [isCounting, countdown]);

  const OtpConfirm = (value) => {

    // alert(value);
    setOtpType(value); // Set to true if confirmed

  };

  return (
    <div className="w-full">
      <style >{`
          
          .bg-primary{
            background-color: ${data?.secondary_color} !important;
          }
          .text-primary{
            color: ${data?.secondary_color} !important;
          }
          .radio-group  {
            color: ${data?.secondary_color} !important;
          }

        `}
      </style>

      {!showOTP && (
        <>
          <div className="2xl:mt-8 mt-6 2xl:text-3xl text-2xl font-bold text-default-900 text-center">
            Forgot Password
          </div>
          <p style={{ color: 'red' }}>{message}</p>

          <form method="post" onSubmit={handleSubmit} className="mt-5 xl:mt-7">
            <div className="space-y-4">
              <div className="flex gap-5">
                <div className="w-full md:w-1/1">
                  <Label htmlFor="firstName" className="text-default-600 mb-3">
                    Enter User Id / Mobile Number <span style={{ color: "red" }}>*</span>
                  </Label>
                  <Input
                    disabled={userCheckData}
                    id="firstName"
                    placeholder="Enter User Id / Mobile Number"
                    type="text"
                    required
                    size={!isDesktop2xl ? "xl" : "lg"}
                    style={{ paddingRight: '10px;' }}
                    value={uniqueIdMobile}
                    onChange={(e) => setUserIdMobile(e.target.value)}
                  />

                </div>
              </div>
              <div className="flex flex-col gap-2">
                <Label
                  htmlFor="password"
                  className="mb-2 font-medium text-default-600"
                >
                  Where would you prefer to receive your verify OTP? Please choose:
                </Label>
                <div className="relative">
                  <RadioGroup
                    className="mb-2 gap-5 md:gap-30 mt-1"
                    value={otpType == 'mobile' ? 'mobile' : 'email'} // Control value with state
                    onValueChange={OtpConfirm} // Handle value change
                  >
                    <RadioGroupItem value="mobile" id="mobile">
                      Registered Mobile
                    </RadioGroupItem>

                    <RadioGroupItem value="email" id="email">
                      Registered Email
                    </RadioGroupItem>
                  </RadioGroup>
                </div>
              </div>

              {
                multipleUser ?

                  <div className="mb-5">
                    <Label
                      htmlFor="password"
                      className="mb-2 font-medium text-default-600"
                    >
                      Please select your preferred login user type
                    </Label>
                    <div className="relative">
                      <select
                        value={uniqueId}
                        onChange={(e) => setUniqueId(e.target.value)}
                        className="w-full bg-background dark:border-700 px-3 file:border-0 file:bg-transparent file:text-sm file:font-medium read-only:bg-background disabled:cursor-not-allowed disabled:opacity-50 transition duration-300 border-default-300 text-default-500 focus:outline-none focus:border-primary disabled:bg-default-200 placeholder:text-accent-foreground/50 border rounded-lg h-12 text-base read-only:leading-[48px]"
                      >
                        <option value="">  Select User Type </option>

                        {multipleUserAccount.map((item, index) => (
                          <option key={index} value={item.unique_id}>
                            {item.designation_id == '3' ? 'Master Distributor' : item.designation_id == '4' ? 'Distributor' : item.designation_id == '5' ? 'Retailer' : 'Employee'} ({item.unique_id})
                          </option>
                        ))}

                      </select>
                    </div>
                  </div>

                  : null
              }

            </div>

            {
              userCheckData == false ?

                <Button
                  className="w-full mt-5"
                  type="submit"
                  disabled={isPending}
                  size={!isDesktop2xl ? "lg" : "md"}
                >
                  {isPending && <Loader2 className="mr-2 h-4 w-4 animate-spin" />}
                  {isPending ? "Loading..." : "Next"}
                  <ArrowRightAlt />
                </Button>

                :

                <Button className="w-full mt-5" disabled={loading} size="lg" type="submit">
                  {loading ? "Submitting..." : "Submit"}
                  {loading && <Loader2 className="mr-2 h-4 w-4 animate-spin" />}

                </Button>
            }


            <div className="mt-5 2xl:mt-8 text-center text-base text-default-600">
              Already Registered?{" "}
              <Link href="/login" className="text-primary">
                {" "}
                Sign In{" "}
              </Link>
            </div>
          </form>
        </>
      )}

      <>
        {showOTP && (
          <>
            <div className="w-full md:w-[480px]">
              <div
                style={{ textAlign: "center" }}
                className="mt-8 text-3xl font-bold text-default-900 mx-auto"
              >
                <h4 style={{ textAlign: "center" }} className="text-10 mb-4">
                  {" "}
                  Please enter the OTP to verify your account
                </h4>
                <p
                  style={{
                    color: "green",
                    textAlign: "center",
                    fontSize: "14px",
                  }}
                >
                  A One-Time Password has been sent to {formatMobileNumber(mobile)}
                </p>
              </div>

              <form className="mt-8" onSubmit={onOTPVerify}>
                <div className="flex text-center">
                  {otpFields.map((index) => (
                    <Input
                      key={`otp-code-${index}`}
                      type="text"
                      id={`otp${index}`}
                      name={`otp${index}`}
                      value={otp[index]}
                      onChange={(e) => handleChange(e, index)}
                      onKeyDown={(event) => handleKeyDown(index, event)}
                      maxLength={1}
                      className="w-10 h-10 sm:w-[60px] sm:h-16 rounded border-default-300 text-center text-2xl font-medium text-default-900"
                      ref={(ref) => (inputRefs.current[index] = ref)}
                    />
                  ))}
                </div>
                <div
                  style={{
                    display: "flex",
                    justifyContent: "flex-end",
                    marginTop: "1rem",
                  }}
                > Didn&lsquo;t receive code? &nbsp;&nbsp;
                  <a
                    href="#"
                    // onClick={otpResend}
                    disabled={loadingOtpResend}
                    style={{
                      color: isHovered ? "blue" : "#000",
                    }}
                  >
                    <span
                      onClick={!isCounting ? otpResend : undefined}
                      className={`cursor-pointer rounded-lg ${isCounting ? 'text-gray-500' : 'text-blue-500'} ${isCounting ? '' : 'hover:text-blue-800'}`}
                    >
                      {isCounting ? `Resend in ${countdown}` : 'Resend OTP'}
                    </span>
                    {loadingOtpResend && (
                      <svg
                        xmlns="http://www.w3.org/2000/svg"
                        width="2em"
                        height="2em"
                        viewBox="0 0 24 24"
                      >
                        <g
                          fill="none"
                          stroke="currentColor"
                          strokeLinecap="round"
                          strokeWidth="2"
                        >
                          <path
                            strokeDasharray="60"
                            strokeDashoffset="60"
                            strokeOpacity="0.3"
                            d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                          >
                            <animate
                              fill="freeze"
                              attributeName="stroke-dashoffset"
                              dur="1.3s"
                              values="60;0"
                            />
                          </path>
                          <path
                            strokeDasharray="15"
                            strokeDashoffset="15"
                            d="M12 3C16.9706 3 21 7.02944 21 12"
                          >
                            <animate
                              fill="freeze"
                              attributeName="stroke-dashoffset"
                              dur="0.3s"
                              values="15;0"
                            />
                            <animateTransform
                              attributeName="transform"
                              dur="1.5s"
                              repeatCount="indefinite"
                              type="rotate"
                              values="0 12 12;360 12 12"
                            />
                          </path>
                        </g>
                      </svg>
                    )}
                  </a>
                </div>
                <div className="mt-6">
                  <Button
                    type="submit"
                    className="w-full"
                    size="lg"
                    disabled={loadingOtpVerify}
                  >
                    Verify Now
                    {loadingOtpVerify && (
                      <svg
                        xmlns="http://www.w3.org/2000/svg"
                        width="2em"
                        height="2em"
                        viewBox="0 0 24 24"
                      >
                        <g
                          fill="none"
                          stroke="currentColor"
                          strokeLinecap="round"
                          strokeWidth="2"
                        >
                          <path
                            strokeDasharray="60"
                            strokeDashoffset="60"
                            strokeOpacity="0.3"
                            d="M12 3C16.9706 3 21 7.02944 21 12C21 16.9706 16.9706 21 12 21C7.02944 21 3 16.9706 3 12C3 7.02944 7.02944 3 12 3Z"
                          >
                            <animate
                              fill="freeze"
                              attributeName="stroke-dashoffset"
                              dur="1.3s"
                              values="60;0"
                            />
                          </path>
                          <path
                            strokeDasharray="15"
                            strokeDashoffset="15"
                            d="M12 3C16.9706 3 21 7.02944 21 12"
                          >
                            <animate
                              fill="freeze"
                              attributeName="stroke-dashoffset"
                              dur="0.3s"
                              values="15;0"
                            />
                            <animateTransform
                              attributeName="transform"
                              dur="1.5s"
                              repeatCount="indefinite"
                              type="rotate"
                              values="0 12 12;360 12 12"
                            />
                          </path>
                        </g>
                      </svg>
                    )}
                  </Button>
                </div>


              </form>
            </div>
          </>
        )}
      </>
    </div>
  );
};

export default Form;
